@@ -50,7 +50,7 @@ rasterGFS <- function(var,
         success <- try(download.file(completeURL, ncFile,
                                      mode='wb', quiet = TRUE),
                        silent=TRUE)
-        if (class(success) == 'try-error') {
+        if (inherits(success, "try-error")) {
             stop('Data not found. Check the date and variables name')
         } else { ## Download Successful!
             message('File(s) available at ', tempdir())
@@ -71,13 +71,15 @@ rasterGFS <- function(var,
 
     ## Use box specification with local files
     if (!is.null(box) & remote==FALSE){
-        if (requireNamespace('rgdal', quietly=TRUE)) {
+        if (requireNamespace('sf', quietly=TRUE)) {
             extPol <- as(extent(box), 'SpatialPolygons')
             proj4string(extPol) <- '+proj=longlat +ellps=WGS84'
-            extPol <- spTransform(extPol, CRS(projection(b)))
+            extPol <- as(sf::st_transform(sf::st_as_sf(extPol),
+                                          sf::st_crs(projection(b))),
+                         "Spatial")
             b <- crop(b, extent(extPol))
         } else {
-            warning("you need package 'rgdal' to use 'box' with local files")
+            warning("you need package 'sf' to use 'box' with local files")
         }
     }
     ## Time index
